Packages

case class Issue(filename: File, message: Message, patternId: Id, line: Line, suggestion: Option[Suggestion], sourceId: Option[String], extraFields: Option[String]) extends Result with Product with Serializable

extraFields

Tool-specific structured metadata as a raw JSON string (e.g. Trivy dependency chains). Kept as a String to preserve this module's dependency-free, Scala-Native-friendly design; JSON (de)serialization of the embedded value is handled by the codecs in codacy-plugins.

Linear Supertypes
Serializable, Product, Equals, Result, AnyRef, Any
Ordering
  1. Alphabetic
  2. By Inheritance
Inherited
  1. Issue
  2. Serializable
  3. Product
  4. Equals
  5. Result
  6. AnyRef
  7. Any
  1. Hide All
  2. Show All
Visibility
  1. Public
  2. Protected

Instance Constructors

  1. new Issue(filename: File, message: Message, patternId: Id, line: Line, suggestion: Option[Suggestion], sourceId: Option[String], extraFields: Option[String])

    extraFields

    Tool-specific structured metadata as a raw JSON string (e.g. Trivy dependency chains). Kept as a String to preserve this module's dependency-free, Scala-Native-friendly design; JSON (de)serialization of the embedded value is handled by the codecs in codacy-plugins.

Value Members

  1. final def !=(arg0: Any): Boolean
    Definition Classes
    AnyRef → Any
  2. final def ##: Int
    Definition Classes
    AnyRef → Any
  3. final def ==(arg0: Any): Boolean
    Definition Classes
    AnyRef → Any
  4. final def asInstanceOf[T0]: T0
    Definition Classes
    Any
  5. def clone(): AnyRef
    Attributes
    protected[lang]
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.CloneNotSupportedException]) @IntrinsicCandidate() @native()
  6. final def eq(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef
  7. val extraFields: Option[String]
  8. val filename: File
  9. final def getClass(): Class[_ <: AnyRef]
    Definition Classes
    AnyRef → Any
    Annotations
    @IntrinsicCandidate() @native()
  10. final def isInstanceOf[T0]: Boolean
    Definition Classes
    Any
  11. val line: Line
  12. val message: Message
  13. final def ne(arg0: AnyRef): Boolean
    Definition Classes
    AnyRef
  14. final def notify(): Unit
    Definition Classes
    AnyRef
    Annotations
    @IntrinsicCandidate() @native()
  15. final def notifyAll(): Unit
    Definition Classes
    AnyRef
    Annotations
    @IntrinsicCandidate() @native()
  16. val patternId: Id
  17. def productElementNames: Iterator[String]
    Definition Classes
    Product
  18. val sourceId: Option[String]
  19. val suggestion: Option[Suggestion]
  20. final def synchronized[T0](arg0: => T0): T0
    Definition Classes
    AnyRef
  21. final def wait(arg0: Long, arg1: Int): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException])
  22. final def wait(arg0: Long): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException])
  23. final def wait(): Unit
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.InterruptedException])

Deprecated Value Members

  1. def finalize(): Unit
    Attributes
    protected[lang]
    Definition Classes
    AnyRef
    Annotations
    @throws(classOf[java.lang.Throwable]) @Deprecated
    Deprecated

    (Since version 9)

Inherited from Serializable

Inherited from Product

Inherited from Equals

Inherited from Result

Inherited from AnyRef

Inherited from Any

Ungrouped